.dashboard-filters {
  margin-bottom: 1rem;
}

.dashboard-grid {
  display: grid;
  grid-auto-columns: minmax(100px, 1fr);
  grid-gap: 0.5rem;
}

.dashboard-card {
  background-color: white;
  padding: 1rem;
  box-shadow: 0px 1px 3px rgba(0, 0, 0, .13);
  border-color: transparent;
  border-radius: 8px;
}

.dashboard-card-title {
  font-size: small;
  font-weight: bold;
}

.dashboard-card-title a {
  text-decoration: none;
}

.dashboard-card-chart {
  width: 100%;
  height: 100%;
}

.chart-container {
  width: 100%;
  height: 70vh;
}
