{% extends "base.html" %}

{% block title %}Dashboards{% endblock %}

{% block nav %}
    <p class="crumbs">
        <a href="{{ urls.instance() }}">home</a>
    </p>
    {{ super() }}
{% endblock %}

{% block body_class %}index{% endblock %}

{% block content %}
  <h1>Dashboards</h1>

  {% if dashboards|length == 0 %}
  <p>No dashboards found</p>
  {% endif %}

  {% for slug, dashboard in dashboards.items() %}
  <h2 style="padding-left: 10px; border-left: 10px solid">
    <a href="{{ urls.path('-/dashboards') }}/{{ slug }}">{{ dashboard.title }}</a>
  </h2>
  <p>{{ dashboard.description }}</p>
  {% endfor %}
{% endblock %}
